indexing
	description: "A flag that will generate a help text and terminate the application"
	author: "Bernd Schoeller"
	copyright: "(c) 2006 Bernd Schoeller (bernd@fams.de)"
	license: "see included README.txt file"
	date: "$Date: 2006/03/27 12:37:40 $"
	revision: "$Revision: 1.3 $"

class OP_DISPLAY_HELP_FLAG

inherit
	
	OP_FLAG
		redefine
			record_occurrence
		end
	KL_SHARED_EXCEPTIONS
	KL_SHARED_FILE_SYSTEM
	KL_SHARED_ARGUMENTS
	
create
	
	make,
	make_with_long_form,
	make_with_short_form

feature {OP_PARSER} -- Parser Interface

	record_occurrence (a_parser: OP_PARSER) is
			-- The option was found during parsing. Display the help text and 
			-- terminate the application.
		do
			display_help_and_die (a_parser)
		end

feature -- Help Display

	display_help_and_die (a_parser: OP_PARSER) is
			-- Display the help text for `a_parser' and die.
		do
			a_parser.error_handler.report_info_message (full_help_text (a_parser))
			exceptions.die (0)
		end

feature {NONE} -- Implementation

	full_help_text (a_parser: OP_PARSER): STRING is
			-- Full help text for `a_parser'
		local
			max_indent: INTEGER
		do
			from
				max_indent := 0
				a_parser.options.start
			until
				a_parser.options.off
			loop
				max_indent := a_parser.options.item_for_iteration.names.count.max (max_indent)
				a_parser.options.forth
			end
			from
				Result := usage_instruction (a_parser) + "%N"
				a_parser.options.start
			until
				a_parser.options.off
			loop
				Result.append (a_parser.options.item_for_iteration.help_text (max_indent + 1) + "%N")
				a_parser.options.forth
			end			
		end

	usage_instruction (a_parser: OP_PARSER): STRING is
			-- Short usage instruction for the program
		local
			args: STRING
			option: OP_OPTION
			usage_head: STRING
		do
			from
				args := ""
				a_parser.options.start
			until
				a_parser.options.off
			loop
				option := a_parser.options.item_for_iteration
				args.append (option.example)
				args.append (" ")
				a_parser.options.forth
			end
			args.append (a_parser.parameters_description)
			usage_head := "usage: "+file_system.basename (arguments.program_name)
			Result := word_wrap (usage_head+args, usage_head.count)
		end

end
